# -*- coding: utf-8 -*-
# Created by lvjiyong on 16/8/20


def sign_up(request):
    """
    注册帐号
    :param request:
    :return:
    """
    pass


def sign_in(request):
    pass


def sign_out(request):
    pass


def change_password(request):
    pass


def change_email(request):
    pass


def change_profile(request):
    pass


def change_detail(request):
    pass



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.contrib.auth.models import User

from django_simple_profile.utils.token import random_str
from .. import models


class MyUserProfile(models.UserProfile):
    class Meta:
        proxy = True

    @classmethod
    def get_by_uid(cls, uid):
        """
        根据个性获取用户信息
        :param uid:
        :return:
        """
        return cls.objects.filter(uid=uid).first()

    @classmethod
    def get_by_domain(cls, domain):
        """
        根据个性获取用户信息
        :param domain:
        :return:
        """
        return cls.objects.filter(domain=domain).first()

    @classmethod
    def get_by_nickname(cls, nickname):
        """
        根据nickname获取用户信息
        :param nickname:
        :return:
        """
        return cls.objects.filter(nickname=nickname).first()

    @classmethod
    def create_user(cls, email, password, nickname):
        """
        创建用户资料
        1.新建用户
        2.创建附加信息
        :param password:
        :param email:
        :param nickname:
        :return:
        """
        user = User()
        user.username = email
        user.set_password(password)
        user.email = email
        user.save(force_insert=True)

        info = cls()
        info.uid = user.id
        info.nickname = nickname
        domain = random_str(6)
        rnd_count_max = 10
        rnd_count_i = 0
        while cls.get_domain(domain):
            rnd_count_i += 1
            domain = random_str(6)
            if rnd_count_i > rnd_count_max:
                raise Exception('无法获取唯一随机域名')

        info.domain = domain
        info.save(force_insert=True)
        return info



# -*- coding: UTF-8 -*-
"""
用户帐号模块
"""

from __future__ import unicode_literals

from django.core import validators
from django.db import models
from django.utils.timezone import now


class UserProfile(models.Model):
    class Meta:
        verbose_name_plural = '用户信息'
        verbose_name = '用户信息'

    uid = models.IntegerField('用户ID', primary_key=True)

    nickname = models.CharField('笔名', max_length=30, db_index=True, unique=True,
                                help_text='请填写您的笔名，该笔名将作为您的公开称呼，且不能与他人相同',
                                validators=[
                                    validators.RegexValidator(
                                        r'^.{3,20}$',
                                        '请使用3-30个中英文数字等组合'
                                    ),
                                ],
                                error_messages={
                                    'unique': "该笔名已存在，请更换",
                                }, )

    domain = models.CharField('个性域名', max_length=30, db_index=True, unique=True,
                              help_text='请使用3-20个字符的字母、数字、-、_组合，且不能与他人相同',
                              validators=[
                                  validators.RegexValidator(
                                      r'^[\w\d\-_]{3,20}$',
                                      '请使用3-20个字符的字母、数字、-、_组合'
                                  ),
                              ],
                              error_messages={
                                  'unique': "该个性域名已存在，请更换",
                              }, )
    time_updated = models.DateTimeField('更新时间', default=now)
    avatar = models.ImageField('头像', max_length=255, blank=True, null=True)
    point = models.IntegerField('积分', default=0)
    message_num = models.IntegerField('消息', default=0)
    settings = models.CharField("扩展配置", max_length=500, default='{}')

    def save(self, *args, **kwargs):
        self.time_updated = now()
        super(UserProfile, self).save(*args, **kwargs)

    def __unicode__(self):
        return self.nickname


class UserDetail(models.Model):
    class Meta:
        verbose_name_plural = '详细资料'
        verbose_name = '详细资料'

    uid = models.IntegerField('用户ID', primary_key=True)
    fullname = models.CharField('姓名', max_length=30, blank=True, null=True)

    sex_type = (
        (None, u'未知'),
        (1, u'男'),
        (0, u'女'),

    )
    sex = models.NullBooleanField('性别', choices=sex_type, blank=True, null=True)
    birthday = models.DateField('生日', default=now, blank=True, null=True)
    city = models.CharField('现居城市', max_length=50, blank=True, null=True)
    address = models.CharField('通讯地址', max_length=100, blank=True, null=True)
    homepage = models.URLField('个人网站', max_length=100, blank=True, null=True)
    signature = models.TextField('自我简介', blank=True, null=True)
    time_updated = models.DateTimeField('更新时间', default=now)

    def save(self, *args, **kwargs):
        self.time_updated = now()
        super(UserDetail, self).save(*args, **kwargs)

    def __unicode__(self):
        return self.fullname



# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from django.contrib import admin

from . import models


@admin.register(models.UserProfile)
class UserInfoAdmin(admin.ModelAdmin):
    """
    用户帐户管理
    """
    search_fields = ['domain', 'uid', 'nickname']
    readonly_fields = ['time_updated']


@admin.register(models.UserDetail)
class UserDetailAdmin(admin.ModelAdmin):
    """
    用户注册验证管理
    """
    search_fields = ['uid', 'fullname']
    readonly_fields = ['time_updated']



# -*- coding: utf-8 -*-

"""
把字典转为属性形式调用

"""
__all__ = ['Parameter']


class Parameter(dict):
    """
    把字典转为属性形式调用
    >>> o = Parameter(a=1)
    >>> o.a
    1
    >>> o['a']
    1
    >>> o.a = 2
    >>> o['a']
    2
    >>> del o.a
    >>> o.a

    """

    def __getattr__(self, key):
        return self.get(key)

    def __setattr__(self, key, value):
        self[key] = value

    def __delattr__(self, key):
        try:
            del self[key]
        except Exception as e:
            raise AttributeError(e)


if __name__ == "__main__":
    import doctest

    doctest.testmod()



# -*- coding: utf-8 -*-
# Created by lvjiyong on 16/8/20

import base64
import hashlib
import time
from random import Random

from django.conf import settings


def md5(msg):
    """
    获取MD5参数
    :param msg:
    :return:
    >>> md5('lvjiyong@19lou.com')
    '2824609856369e45783ec2674792b0f6
    """
    if msg:
        return hashlib.md5(msg.encode('utf-8')).hexdigest()


def get_token(msg, timestamp):
    return md5('{msg}{timestamp}{key}'.format(msg=msg, timestamp=timestamp, key=settings.SYN_SECRET_KEY))


def check(msg, token, timestamp, expired=3600):
    """
    确定加密token是否正确
    :param msg:
    :param token:
    :param timestamp:
    :param expired:
    :return:
    """
    if float(timestamp) + expired > time.time():
        if token == get_token(msg, timestamp):
            return True


def random_str(randomlength=6):
    chars = 'abcdefghijklmnopqrstuvwxyz0123456789'
    length = len(chars) - 1
    random = Random()
    return ''.join([chars[random.randint(0, length)] for i in list(range(randomlength))])


def base64_encode(content):
    return str(base64.encodebytes(content.encode(encoding="utf-8"))).strip('b').strip('\'').strip('\\n')



# -*- coding: UTF-8 -*-

from os.path import dirname, join

from setuptools import setup, find_packages

with open(join(dirname(__file__), 'VERSION'), 'rb') as f:
    version = f.read().decode('utf-8').strip()

with open(join(dirname(__file__), 'README.md'), 'rb') as f:
    description = f.read().decode('utf-8').strip()

APP_NAME = 'django-simple-profile'

setup(
    name=APP_NAME,
    version=version,
    description=APP_NAME,
    author="lvjiyong",
    author_email='lvjiyong',
    url="https://github.com/lvjiyong/%s" % APP_NAME,
    license="Apache2.0",
    long_description=description,
    maintainer='lvjiyong',
    platforms=["any"],
    maintainer_email='lvjiyong@gmail.com',
    include_package_data=True,
    packages=find_packages(exclude=('tests', 'docs', 'django_test')),
    install_requires=['django'],
)



# -*- coding: UTF-8 -*-

from __future__ import unicode_literals

from .. import models


class MyUserDetail(models.UserDetail):
    class Meta:
        proxy = True

    @classmethod
    def get_uid(cls, uid):
        """
        根据个性获取用户信息
        :param uid:
        :return:
        """
        return cls.objects.filter(uid=uid).first()



# -*- coding: utf-8 -*-
import json

from .parameter import Parameter
from ..api import user_detail, user_profile


def add_user_profile(request):
    profile = Parameter()
    if request.user.is_authenticated:
        profile = user_profile.MyUserProfile.get_uid(request.user.id) or profile
        profile.settings = json.loads(profile.get('settings') or '{}')
    return {'user_profile': profile}


def add_user_detail(request):
    detail = Parameter()
    if request.user.is_authenticated:
        detail = user_detail.MyUserDetail.get_uid(request.user.id) or detail
    return {'user_detail': detail}
